@@ -1,3 +1,18 @@
+#' Raman spectrum of methanol (CH3OH)
+#' 
+#' @format A list containing 2 variables:
+#' \describe{
+#'   \item{wavenumbers}{a numeric Vector of 331 wavenumbers (cm^-1)}
+#'   \item{wavenumbers}{a \code{1 * 331} Matrix of intensity values (a.u.)}
+#'  }
+"methanol"
+
+#' Surface-enhanced Raman spectram of tetramethylrhodamine+DNA (T20)
+#' 
+#' @format A ``hyperSpec`` spc object
+#' @source \url{https://pure.strath.ac.uk/portal/files/43595106/Figure_2.zip}
+"TAMRA"
+
 #' SMC particles for TAMRA+DNA (T20)
 #'
 #' Posterior distribution for pseudo-Voigt parameters, obtained by running
@@ -21,5 +36,13 @@
 #'   \item{times}{history of times for each SMC iteration}
 #'   \item{time}{computation time taken by the SMC algorithm}
 #' }
-#' @source \url{https://pure.strath.ac.uk/portal/files/43595106/Figure_2.zip}
-"result"
\ No newline at end of file
+"result"
+
+#' SMC particles for methanol (CH3OH)
+#'
+#' Posterior distribution for pseudo-Voigt parameters, obtained by running
+#' `fitVoigtPeaksSMC` on a Raman spectrum of methanol with 4 peaks.
+#' For details, refer to the vignette.
+#'
+#' @format A list containing 15 variables.
+"result2"
